/*
------------------------------------------------------------
	ce_stdio.c - SDL backend for primitive stdio
------------------------------------------------------------
 * Copyright (C) David Olofson, 2002
 *
 * This code is released under the terms of the GNU LGPL.
 */

#include <stdio.h>
#include <stdarg.h>
#include "ce_stdio.h"

static int stdio_open(int w, int h, int flags)
{
	_ce_screen_w = w;	/* Whatever... */
	_ce_screen_h = h;
	_ce_backend = &_ce_stdio;
	return 1;
}


static void stdio_close(void)
{
}


static int stdio_getc(void)
{
	return getchar();
}

static int stdio_put_fast(ce_rect_t rect, ce_character_t *buffer, int pitch)
{
	/*
	 * This probably shouldn't really be used with this backend...
	 */
	int x, y;
	for(y = 0; y < rect.h; ++y)
	{
		for(x = 0; x < rect.w; ++x)
			if(buffer[y*pitch + x].c >= 32)
				putchar(buffer[y*pitch + x].c);
			else
				putchar('.');
		puts("\n");
	}
	return 0;
}

static int stdio_scanf(ce_window_t *window, const char *fmt, va_list args)
{
/* Where the h*ll is vscanf() on Mandrake 8.0!? */
//	return vscanf(fmt, args);
	return -1;
}


static int stdio_putchar(ce_window_t *window, int c)
{
	return putchar(c);
}


static int stdio_puts(ce_window_t *window, const char *s)
{
	return puts(s);
}


static int stdio_printf(ce_window_t *window, const char *fmt, va_list args)
{
	return vprintf(fmt, args);
}


static int stdio_redirect_stdio(ce_window_t *window)
{
	return 0;	/* *We* are using stdio, so... */
}


static int stdio_cursor_at(int x, int y)
{
	return 0;
}


ce_backend_t _ce_stdio = {
	/* --- required --- */
	stdio_open,	/* open */
	stdio_close,	/* close */
	stdio_getc,	/* getc */
	stdio_put_fast,	/* put_fast */

	/* --- optional --- */
	NULL,		/* put */

	NULL,		/* kbhit */
	stdio_scanf,	/* scanf */
	stdio_putchar,	/* putchar */
	stdio_puts,	/* puts */
	stdio_printf,	/* printf */

	stdio_redirect_stdio,	/* redirect_stdio */

	NULL,		/* locate */
	NULL,		/* where_x */
	NULL,		/* where_y */

	stdio_cursor_at,	/* cursor_at */
	NULL		/* set_palette */
};
